萤火虫之墓 (豆瓣)
Description: 萤火虫之墓电影简介和剧情介绍,萤火虫之墓影评、图片、预告片、影讯、论坛、在线购票
Keywords: 萤火虫之墓,火垂るの墓,萤火虫之墓影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.212豆瓣电影Top250

# 萤火虫之墓 火垂るの墓 (1988)

导演: 高畑勋
编剧: 高畑勋 / 野坂昭如
主演: 辰己努 / 白石绫乃 / 志乃原良子 / 山口朱美 / 端田宏三
类型: 剧情 / 动画 / 战争
制片国家/地区: 日本
语言: 日语
上映日期: 1988-04-16(日本)
片长: 89 分钟
又名: 再见萤火虫(港) / 萤火挽歌 / 火帘之墓 / Hotaru no haka / Tombstone for Fireflies / Grave of the Fireflies / Tomb of the Fireflies
IMDb: tt0095327
豆瓣评分
引用
8.7
390716人评价
5星
53.9%
4星
32.7%
3星
10.0%
2星
1.7%
1星
1.7%
好于 96% 动画片
好于 96% 战争片
想看 看过
评价:
推荐

## 萤火虫之墓的剧情简介 · · · · · ·

美日战争爆发，14岁的清太带着年幼的妹妹到处逃命，当他们到达防空洞的时候，母亲已身受重伤，没过多久便不久人世。两兄妹自此过着相依为命的日子。他们只好投靠了母亲的姐妹，纵使他们把家里所有的家当都送给了阿姨，但当食物吃完，他们就越感到了寄人篱下的感觉，清太决定带着妹妹离开独自生活。火灾硝烟中的生活并不好过，清太为了妹妹四处偷取食物，但妹妹还是严重营养不良…… ©豆瓣

## 萤火虫之墓的演职员 · · · · · · ( 全部 11 )

- 高畑勋 导演
- 山口朱美 配 西宮のおばさん
- 志乃原良子 配 清太・節子の母
- 白石绫乃 配 節子
- 辰巳努 配 清太
- 野坂昭如 编剧

## 萤火虫之墓的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片629 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  幽灵公主

  风之谷

  天空之城

  哈尔的移动城堡

  魔女宅急便

  猫的报恩

  红猪

  大闹天宫

  百变狸猫

  侧耳倾听

我要写短评

## 萤火虫之墓的短评 · · · · · · ( 全部 80580 条 )

热门 / 最新 / 好友

### 6306 有用 张天师 看过 2006-11-06 10:28:24

又精致又催人泪下。可是二战时期的日本一点也不值得让人那么同情

### 2911 有用 大头绿豆 看过 2006-09-17 05:57:12

“我们做错了什么？”这话应该由日本人说么，即使是平民？妹妹的神态、动作、配音都绝了。

### 2193 有用 大兒童 看过 2009-08-16 13:17:23

日本人博取同情的功利 是中国的N倍。

### 660 有用 单线程青年 看过 2007-05-12 09:14:55

虽然事先知道这是个煽情的片子，知道它注定是个悲剧，还是哭了。告诉你这是个悲伤电影，在你准备好的情况下，还能达到效果，的确是个好片子

### 3218 有用 露娜peace 看过 2006-06-19 11:31:42

我发誓我再不敢看第二遍

> 更多短评 80580条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 萤火虫之墓的影评 · · · · · · ( 全部 1573 条 )

热门 / 最新 / 好友
[己注销] 2008-06-19 21:09:02

## 批判《再见萤火虫》

相信有的朋友会注意到，尽管我的题目起得很尖锐，但我还是给出了四星的高分，因此，我希望你能认认真真地看完我全部的发言，然后再发表对我的评论的看法。 要说吉卜力当中，有哪一部作品受到最多的争议，那非高畑勋执导的《再见萤火虫》莫属。这部作品可谓是感动了不少人，也触... (展开)
4385 945 1463回应 收起
土豆 2010-06-29 23:18:42

## 剧透：我是怎么把妹妹养死的

日本二战战败前夕，美日之战进入最后尾声 美国的飞机时不时扔几个燃烧弹，日本特色的小木屋熊熊大火 妈妈死了 爸爸征战了 就剩男主角和小萝莉妹妹了 好吧 怎么办 —————————————— 好，从这一刻开始，男主角开始养死妹妹了。 1、学校炸了，上不了学，寄宿在姨妈... (展开)
3088 917 1044回应 收起
Ridden 2008-07-14 14:56:39

## 拜托，不是宫崎峻，是高畑勋！

豆瓣成员常用的标签: 宫崎骏(5840) 稍微有点耐心，看下介绍就知道，这部片子跟宫崎骏完全没有关系。导演和编剧都不是他。 宫崎骏和高畑勋应该是对手的关系： （1）都是吉卜力吉卜力出品的。 （2）1988年，宫崎骏与高畑勋同时开工，各自组建队伍，双方展开竞争。宫崎峻完成了... (展开)
670 93 243回应 收起
敕勒歌 2009-01-08 18:32:43

## 萤火虫漫天，小日本感动了我

昭和20年9月21日夜，我死了。” 影片一开始的这句台词就紧紧地抓住了我的心，在一片血晕的红色中，一个少年开始了回忆，这是他灵魂的回忆，他已经死了。这注定是一场悲剧…… 可爱的小节子正在为死去的萤火虫挖坟墓，哥哥清太走过来问妹妹在干什么，节子说：“造坟墓，妈妈没... (展开)
1014 219 228回应 收起
小黑 2010-03-29 21:40:06

## 我不能理解为什么有人要哭

首先我要声明，我第一不是FQ,第二我不仇日 但我依旧觉得这孩子活该，为什么活该不是因为日本侵略这些原因，而是这孩子本身的原因。 那些哭了的人请你代入自己想一下，如果你在一个全国都很困难，粮食要靠供给的时代，借住在自己亲戚家，然后你每天屁活不干，天天就四处玩，到点... (展开)
868 498 506回应 收起
migi 2007-07-11 13:44:18

## 丧钟为何而鸣

当时看这部影片时，虽然感觉伤感，但其实更多的感觉是愤怒，那个任性哥哥凭什么因为自己的意气用事把年幼的妹妹带向死亡。 实际上，高畑勋是用哥哥这一角色来象征日本军国主义、日本帝国，年幼的妹妹象征盲从的日本人民，这部片子不是叫人伤感，而是促人反思，反思丧钟为何而... (展开)
170 30 34回应 收起
蓮 2012-08-14 14:02:08

## 哪里让人感动了

这篇影评可能有剧透

观影感受如标题 然后看见影评里对姨妈的谩骂 谴责对待亲戚的小孩不该这么冷漠是害死兄妹俩的元凶balalala之后 倒是很想为姨妈说几句 不管是不是本着有利可图的心理收留了兄妹俩最初还是对他们很好的。之后姨妈拿清太妈妈的衣服换了米自己拿了一部分补贴家里也无可厚非吧。住个... (展开)
144 25 13回应 收起
bekey 2018-01-23 17:01:25

## 萤火虫之墓，破灭的更是希望

这篇影评可能有剧透

抛开政治因素，只谈文艺，该片还是很值得推荐的。 在我心中对标题萤火虫之墓的理解，即是对节子和哥哥清太的生命和希望终结的预示，并全部都投影到了一盒水果糖里。 片子伊始，清太一家过着中层阶级生活，父亲是有地位有权势的军队大尉，母亲则是貌美贤惠的家庭... (展开)
133 8 25回应 收起
附离 2012-06-01 22:18:52

## 看着这哥就火大

这哥十四岁了,不算小,遭受父母双亡如此重大的人生变故却还不知长大,虽寄姨妈篱下,但至少有地可寄,却不懂为人做事,还把自己当少爷,我说哥，当下世道这么难，好歹你得主动做个家务什么的，也不至于姨妈这么难看你。其实就这哥害死妹的,让妹妹住山洞,还偷窃,最后自己沦落成乞丐死... (展开)
118 29 33回应 收起

> 更多影评 1573篇

添加新讨论

## 讨论区 · · · · · ·

关于豆瓣top250评选标准之疑问 | 来自红夜 | 15 回应 | 2022-11-24 21:05:21
节子哥为啥不工作 | 来自且敛风翼 | 3 回应 | 2022-11-24 21:03:01
不喜欢妹妹，我是一个人嘛 | 来自璐瑶！酱~ | 40 回应 | 2022-11-24 21:02:19
二战背景下的日本普通民众难道不值得同情吗 | 来自不吹灰 | 117 回应 | 2022-11-24 20:52:47
擦亮眼睛吧，这不是反战影片 | 来自Lai Lai Hei | 258 回应 | 2022-11-23 08:54:23

> 去这部影片的讨论区（全部343条）

## 关于《萤火虫之墓》的问题 · · · · · · ( 全部18个 )

- 在海边的乡下为什么不抓螃蟹海鲜填饱肚子？ 6人回答
- 短评中说无耻活该的几条，你们还有没有人性？ 18人回答

> 全部18个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 【爱看动画】 (影志)
- 日本动画推荐 (恶魔的步调)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- momo
  7分钟前 看过
- 杨坚强
  10分钟前 看过
- 想不出来呀
  11分钟前 看过

617437人看过 / 179874人想看

订阅萤火虫之墓的评论:
feed: rss 2.0